try:  # pre 1.6
    from django.conf.urls.defaults import url, patterns
except ImportError:
    from django.conf.urls import url, patterns

from .forms import FileForm

urlpatterns = patterns(
    '',
    url(
        '^upload/(?P<upload_to>.*)/(?P<max_width>\d+)/(?P<max_height>\d+)/(?P<crop>\d+)',
        'ajaximage.views.ajaximage',
        {'form_class': FileForm},
        name='ajaximage'
    ),
)



import os
from PIL import Image, ImageOps
from StringIO import StringIO
from django.core.files.base import ContentFile
from django.core.files.uploadedfile import SimpleUploadedFile


def resize(file_, max_width=0, max_height=0, crop=0):
    max_width = int(max_width)
    max_height = int(max_height)
    crop = int(crop)
    
    if(max_width is 0 and max_height is 0):
        return file_
        
    max_width = 9999 if max_width is 0 else max_width
    max_height = 9999 if max_height is 0 else max_height
    
    size = (max_width, max_height)
    image = Image.open(file_)
    
    if(image.mode == 'RGBA'):
        image.load()
        background = Image.new('RGB', image.size, (255, 255, 255))
        background.paste(image, mask=image.split()[3])
        image = background
    
    temp = StringIO()
    
    if(crop is 1):
        image = ImageOps.fit(image, size, Image.ANTIALIAS)
    else:
        image.thumbnail(size, Image.ANTIALIAS)
    
    image.save(temp, 'jpeg')
    temp.seek(0)
    
    return SimpleUploadedFile(file_.name,
                              temp.read(),
                              content_type='image/jpeg')


import os
from django.forms import widgets
from django.utils.safestring import mark_safe
from django.core.urlresolvers import reverse


HTML = """
<div class="ajaximage" data-url="{upload_url}">
    <a class="link" target="_blank" href="{file_url}"><img src="{file_url}"></a>
    <a class="remove" href="#remove">Remove</a>
    <input type="hidden" value="{file_path}" id="{element_id}" name="{name}" />
    <input type="file" class="fileinput" />
    <div class="progress progress-striped active">
        <div class="bar"></div>
    </div>
</div>
"""


class AjaxImageEditor(widgets.TextInput):

    class Media:
        js = (
            'shared-bg/js/jquery-1.10.0.min.js',
            'shared-bg/js/jquery.iframe-transport.js',
            'shared-bg/js/jquery.ui.widget.js',
            'shared-bg/js/jquery.fileupload.js',
            'ajaximage/js/ajaximage.js',
        )
        css = {
            'all': (
                'shared-bg/css/bootstrap-progress.min.css',
                'ajaximage/css/styles.css',
            )
        }

    def __init__(self, *args, **kwargs):
        self.upload_to = kwargs.pop('upload_to', '')
        self.max_width = kwargs.pop('max_width', '')
        self.max_height = kwargs.pop('max_height', '')
        self.crop = kwargs.pop('crop', '')
        super(AjaxImageEditor, self).__init__(*args, **kwargs)

    def render(self, name, value, attrs=None):
        final_attrs = self.build_attrs(attrs)
        element_id = final_attrs.get('id')
        
        kwargs = {'upload_to': self.upload_to,
                  'max_width': self.max_width,
                  'max_height': self.max_height,
                  'crop': self.crop}
        
        upload_url = reverse('ajaximage', kwargs=kwargs)
        file_path = value if value else ''

        # use FieldFile.url - get url using storage backend
        file_url = value.url if value else ''

        file_name = os.path.basename(file_url)

        output = HTML.format(upload_url=upload_url,
                             file_url=file_url,
                             file_name=file_name,
                             file_path=file_path,
                             element_id=element_id,
                             name=name)

        return mark_safe(unicode(output))
